#
# spec file for package cosmic-session
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cosmic-session
Version:        1.0.0~alpha4+0
Release:        1.1
Summary:        Session manager for the COSMIC desktop environment
License:        GPL-3.0-only
URL:            https://github.com/pop-os/cosmic-session
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst
Source2:        %{name}.dconf
Patch0:         fix-justfile.patch
Patch1:         leap-fix-justfile.patch
BuildRequires:  cargo-packaging
BuildRequires:  just
Requires:       switcheroo-control

%description
%{summary}.

%prep
%autosetup -N -a1
%patch -P0 -p1
%if 0%{?suse_version} < 1600
%patch -P1 -p1
%endif

%build
just build-release

%install
just rootdir=%{buildroot} prefix=%{_prefix} install
install -Dm0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/dconf/profile/cosmic

%check
%{cargo_test}

%files
%license LICENSE.md
%{_bindir}/%{name}
%{_bindir}/start-cosmic
%{_datadir}/applications/cosmic-mimeapps.list
%{_datadir}/wayland-sessions/cosmic.desktop
%{_prefix}/lib/systemd/user/cosmic-session.target
%dir %{_datadir}/wayland-sessions
%dir %{_sysconfdir}/dconf
%dir %{_sysconfdir}/dconf/profile
%{_sysconfdir}/dconf/profile/cosmic

%changelog
* Fri Dec  6 2024 Richard Rahl <rrahl0@opensuse.org>
- add cosmic dconf config
* Fri Dec  6 2024 rrahl0@opensuse.org
- Update to version 1.0.0~alpha4+0:
  * session: Add custom dconf profile
  * cleanup
  * feat: try to gracefully shut down settings daemon when exiting
  * feat: a11y
  * main: Only launch xdg-portal on COSMIC
  * comp: Allow to specify different compositors
  * Launch `cosmic-idle`
  * fix: log cosmic-settings-daemon output
  * Handle inode/mount-point with cosmic-files
  * Launch cosmic-files-applet
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha3:
  * Add store to mimeapps, cleanup unused entries
  * Handle flatpakref with cosmic-store
  * Handle inode/mount-point with cosmic-files
  * fix: log cosmic-settings-daemon output
  * Launch cosmic-idle
  * comp: Allow to specify different compositors
  * main: Only launch xdg-portal on COSMIC
* Thu Oct 17 2024 John Vandenberg <jayvdb@gmail.com>
- Add dependency on cosmic-settings-daemon
* Wed Sep 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha2:
  * Simplify is_systemd_used
  * Fix compile-time errors with --no-default-features
  * Builds without systemd should no longer hard depend on journald
  * Make failure to connect to journald a warning, not a hard error
  * start-cosmic: Set QT auto scaling env variables
* Thu Aug  8 2024 Richard Rahl <rrahl0@opensuse.org>
- standardize packaging with also fixes for miscellaneous hardcoding
  filenames, using @PARENT_TAG where applicable, and be more specific
  with files in the %%files section (so no non-wanted files are getting
  added
* Wed Aug  7 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 1.0.0~alpha1:
  * Depend on switcheroo-control
- enable leap with patch leap-fix-justfile.patch (thanks to vyvir)
- fix justfile with fix-justfile.patch
* Thu Mar 14 2024 Richard Rahl <rrahl0@proton.me>
- initial packaging
